# encoding: utf-8

# File:	clients/novell-lum_auto.ycp
# Package:	Configuration of novell-lum
# Summary:	Client for autoinstallation
# Authors:	Stephen T. Bunch <sbunch@novell.com>
#
# $Id: novell-lum_auto.ycp,v 1.1.2.2 2005/04/21 20:30:32 mclark Exp $
#
# This is a client for autoinstallation. It takes its arguments,
# goes through the configuration and return the setting.
# Does not do any changes to the configuration.

# @param function to execute
# @param map/list of novell-lum settings
# @return [Hash] edited settings, Summary or boolean on success depending on called function
# @example map mm = $[ "FAIL_DELAY" : "77" ];
# @example map ret = WFM::CallFunction ("novell-lum_auto", [ "Summary", mm ]);
module Yast
  class NovellLumAutoClient < Client
    def main
      Yast.import "UI"

      textdomain "novell-lum"

      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("NovellLum auto started")

      Yast.import "NovellLum"
      Yast.include self, "novell-lum/wizards.rb"

      @ret = nil
      @func = ""
      @param = {}

      # Check arguments
      if Ops.greater_than(Builtins.size(WFM.Args), 0) &&
          Ops.is_string?(WFM.Args(0))
        @func = Convert.to_string(WFM.Args(0))
        if Ops.greater_than(Builtins.size(WFM.Args), 1) &&
            Ops.is_map?(WFM.Args(1))
          @param = Convert.to_map(WFM.Args(1))
        end
      end
      Builtins.y2debug("func=%1", @func)
      Builtins.y2debug("param=%1", @param)

      # Create a summary
      if @func == "Summary"
        @ret = Ops.get_string(NovellLum.Summary, 0, "")
      # Reset configuration
      elsif @func == "Reset"
        NovellLum.Import({})
        @ret = {}
      # Change configuration (run AutoSequence)
      elsif @func == "Change"
        #    import "OesLdap"; // FIXME: is this needed anymore?
        #    OesLdap::autoyast_tool = true; // FIXME: is this needed anymore?
        @ret = NovellLumAutoSequence()
      # Import configuration
      elsif @func == "Import"
        @ret = NovellLum.Import(@param)
      # Return actual state
      elsif @func == "Export"
        NovellLum.Read if NovellLum.Settings == nil || NovellLum.Settings == {}
        NovellLum.auto_clone = true
        @ret = NovellLum.Export
      # Return needed packages
      elsif @func == "Packages"
        @ret = NovellLum.AutoPackages
      # Read current state
      elsif @func == "Read"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        @ret = NovellLum.Read
        Progress.set(@progress_orig)
      # Write givven settings
      elsif @func == "Write"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        NovellLum.write_only = true
        @ret = NovellLum.Write
        Progress.set(@progress_orig)
      # Return if configuration  was changed
      # return boolean
      elsif @func == "GetModified"
        NovellLum.globals_configured = true
        @ret = NovellLum.globals_configured
      # Set modified flag
      # return boolean
      elsif @func == "SetModified"
        NovellLum.globals_configured = true
        @ret = true
      else
        Builtins.y2error("Unknown function: %1", @func)
        @ret = false
      end

      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("NovellLum auto finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::NovellLumAutoClient.new.main
