# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	clients/novell-lum_proposal.ycp
# Package:	Configuration of novell-lum
# Summary:	Proposal function dispatcher.
# Authors:	Stephen T. Bunch <sbunch@novell.com>
#
# $Id: novell-lum_proposal.ycp,v 1.1.2.6 2005/02/10 21:20:32 sbunch Exp $
#
# Proposal function dispatcher for novell-lum configuration.
# See source/installation/proposal/proposal-API.txt
module Yast
  class NovellLumProposalClient < Client
    def main

      textdomain "novell-lum"

      Yast.import "NovellLum"
      Yast.import "Progress"
      Yast.import "NovellLDAP"
      Yast.import "NovellPatterns"
      Yast.import "NovellAddonInstall"
      Yast.import "NovellUtils"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("NovellLum proposal started")

      @func = Convert.to_string(WFM.Args(0))
      @param = Convert.to_map(WFM.Args(1))
      @ret = {}

      Builtins.y2milestone("NovellLum proposal function: %1", @func)

      # create a textual proposal
      if @func == "MakeProposal"
        @proposal = ""
        @warning = ""
        @warning_level = nil
        @force_reset = Ops.get_boolean(@param, "force_reset", false)

        if NovellUtils.EdirAskUserFlag("lum") # If edir changed, then we need to recompute the defaults.
          @force_reset = true
          Builtins.y2milestone(
            "novell-lum.MakeProposal:force_reset set to true due to ask user flag."
          )
        end

        if @force_reset || !NovellLum.proposal_valid
          NovellLum.proposal_valid = true
          @progress_orig = Progress.set(false)
          NovellLum.Read
          Progress.set(@progress_orig)
        end
        @sum = NovellLum.Summary
        @proposal = Ops.get_string(@sum, 0, "")
        @ret = NovellAddonInstall.ConstructProposal("novell-lum", @proposal)
      # validate the current values
      elsif @func == "ValidateValues"
        @ret = { "errors" => false }

        if !Mode.update && !Mode.autoupgrade
          if Ops.get_string(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_PASSWORD",
              ""
            ) == "" &&
              Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == "" ||
              Ops.get_string(
                NovellLum.Settings,
                "CONFIG_LUM_PARTITION_ROOT",
                ""
              ) == "" ||
              Ops.get_string(NovellLum.Settings, "CONFIG_LUM_WS_CONTEXT", "") == ""
            Ops.set(@ret, "errors", true)
          end
        end
      # run the module
      elsif @func == "AskUser"
        Builtins.sleep(750)
        @chosen_id = Ops.get(@param, "chosen_id")
        Builtins.y2milestone(
          "Linux User Management proposal changing id %1",
          @chosen_id
        )

        # Configure now
        if @chosen_id == "novell-lum--configure_now"
          Ops.set(NovellAddonInstall.products_to_configure, "novell-lum", true)
          @ret = { "workflow_sequence" => :next }
        elsif @chosen_id == "novell-lum--configure_later"
          Ops.set(NovellAddonInstall.products_to_configure, "novell-lum", false)
          @ret = { "workflow_sequence" => :next }
        else
          @stored = NovellLum.ExportSettings
          @seq = Convert.to_symbol(
            WFM.CallFunction("novell-lum", [path(".propose")])
          )
          NovellLum.Import(@stored) if @seq != :next
          Builtins.y2debug("stored=%1", @stored)
          Builtins.y2debug("seq=%1", @seq)
          @ret = { "workflow_sequence" => @seq }
        end
      # create titles
      elsif @func == "Description"
        # Determine if we should be in the proposal screen or not.
        @force_proposal = Ops.get_boolean(@param, "force_proposal", false)
        @isSelected = NovellPatterns.IsPatternInstalled("novell-lum") # FIXME: is this needed anymore?
        @isSelected = @isSelected &&
          NovellAddonInstall.IsProductSelected("novell-lum")
        Builtins.y2milestone(
          "Proposal:IsSelected:novell-lum(novell-lum): %1",
          @isSelected
        )
        if @isSelected || @force_proposal
          @ret = {
            # Rich text title for NovellLum in proposals
            "rich_text_title" => _(
              "Linux User Management"
            ),
            # Menu title for NovellLum in proposals
            "menu_title"      => _(
              "&Linux User Management"
            ),
            "id"              => "novell-lum"
          }
        else
          @ret = {}
        end
      # write the proposal
      elsif @func == "Write"
        NovellLum.Write
      else
        Builtins.y2error("unknown function: %1", @func)
      end

      # Finish
      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("NovellLum proposal finished")
      Builtins.y2milestone("----------------------------------------")
      deep_copy(@ret)

      # EOF
    end
  end
end

Yast::NovellLumProposalClient.new.main
