# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	include/novell-lum/dialogs.ycp
# Package:	Configuration of novell-lum
# Summary:	Dialogs definitions
# Authors:	Stephen T. Bunch <sbunch@novell.com>
#
# $Id: dialogs.ycp,v 1.1.2.15 2005/06/16 19:04:25 rhaslam Exp $
module Yast
  module NovellLumDialogsInclude
    def initialize_novell_lum_dialogs(include_target)
      Yast.import "UI"

      textdomain "novell-lum"

      Yast.import "Label"
      Yast.import "Wizard"
      Yast.import "NovellLum"
      Yast.import "EdirUtils"
      Yast.import "NovellUtils"
      Yast.import "NovellValidators"
      Yast.import "NovellLDAP"
      Yast.import "NovellLDAPUI"
      Yast.import "ValidationHelpers"
      Yast.import "NovellLdapBrowser"
      Yast.import "Edirectory"
      Yast.import "Report"
      Yast.import "IP"
      Yast.include include_target, "novell-lum/helps.rb"
      Yast.include include_target, "novell-lum/complex.rb"
    end

    def PromptIfNeededForEdirAdminPassword
      useXad = false

      if NovellLum.xadMode
        xad_tree_admin_context = Ops.get_string(
          NovellLDAP.Settings,
          "XAD_TREE_ADMIN_CONTEXT",
          ""
        )
        if xad_tree_admin_context != nil && xad_tree_admin_context != ""
          useXad = true
        end # if this value is set at all, then it is the eDir admin (in spite of xad name)
      end
      Builtins.y2milestone(
        "NovellLum.PromptIfNeededForEdirAdminPassword:use xad:%1",
        useXad
      )

      if useXad
        if Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.XadTreeAdminPasswordDialog
        end
      else
        if Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.AdminPasswordDialog
        end
      end
      Builtins.y2milestone(
        "NovellLum.PromptIfNeededForEdirAdminPassword:useXad %1",
        useXad
      )
      useXad
    end

    # Configure2 dialog
    # @return dialog result
    def LumDialog
      gbl_ldap_user = ""
      useBrowser = false

      if Mode.update || Mode.autoupgrade
        Popup.Message(NovellUtils.noConfigMessage)
        Builtins.y2milestone(
          "NovellLum.LumDialog:skipping GUI since we are in upgrade mode."
        )
        return :skip
      end

      # NovellLum configure2 dialog caption
      caption = _("Linux User Management Configuration")

      ldap_server = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_LDAP_SERVER",
        ""
      )
      if ldap_server == nil || !NovellLDAP.AddressExists(ldap_server, nil)
        ldap_server = ""
      end

      partContext = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_PARTITION_ROOT",
        ""
      )
      if partContext == nil
        name = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_ADMIN_CONTEXT",
          ""
        )
        name = "" if name == nil
        partContext = NovellUtils.GetContextNDS(name)
        partContext = "" if partContext == nil
      end
      workContext = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_WS_CONTEXT",
        ""
      )
      partContext = NovellUtils.Nds2Ldap(partContext)
      workContext = partContext if workContext == nil

      user = Ops.get_string(NovellLum.Settings, "CONFIG_LUM_PROXY_USER", "")
      user = "" if user == nil
      password = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_PROXY_USER_PASSWORD",
        ""
      )

      commonProxyName = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_COMMON_PROXY",
        ""
      )
      commonProxyPassword = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_COMMON_PROXY_PASSWORD",
        ""
      )

      server_list = Ops.get_list(
        NovellLDAP.Settings,
        "CONFIG_LDAP_SERVERS_LIST",
        []
      )

      change_umask = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_RESTRICT_ACCESS",
        ""
      )
      change_umask = "yes" if change_umask == nil || change_umask == ""

      cUmask = true
      cUmask = false if Builtins.tolower(change_umask) != "yes"

      useCommonProxy = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_DO_PROXY",
        ""
      )

      server_list_widget = NovellLDAPUI.ServerListWidget(
        server_list,
        _("Directory Server Address"),
        ldap_server,
        true,
        :combo
      )
      ldap_widget = Ops.get_term(server_list_widget, "term") { VBox(:Empty) }

      # We need to know this later during Write() if the user changed the value.
      orgWorkContext = NovellUtils.Nds2Ldap(workContext)
      admin_group = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_ADMIN_GROUP",
        ""
      )
      orgAdminGroup = NovellUtils.Nds2Ldap(admin_group)
      contents = HVSquash(
        VBox(
          ldap_widget,
          MinWidth(
            45,
            HBox(
              TextEntry(
                Id(:partContext),
                _("Unix config context (e.g. o=microfocus)"),
                partContext
              ),
              VBox(Label(""), PushButton(Id(:browse_partContext), _("Browse")))
            )
          ),
          MinWidth(
            45,
            HBox(
              TextEntry(
                Id(:workContext),
                _("UNIX workstation context (e.g. o=microfocus)"),
                workContext
              ),
              VBox(Label(""), PushButton(Id(:browse_workContext), _("Browse")))
            )
          ),
          MinWidth(
            45,
            HBox(
              TextEntry(
                Id(:admin_group),
                Opt(:notify),
                _("Admin group name with context"),
                admin_group
              ),
              VBox(Label(""), PushButton(Id(:browse_admingroup), _("Browse")))
            )
          ),
          MultiLineEdit(
            Id(:user),
            Opt(:notify),
            _("Proxy User for LUM Management (Optional)"),
            user
          ),
          VBox(
            Left(
              CheckBox(
                Id(:useCommonProxy),
                Opt(:notify),
                _("Use OES Common Proxy User"),
                true
              )
            )
          ),
          VBox(
            VSpacing(1),
            Left(
              CheckBox(
                Id(:changeUmask),
                _("Restrict &access to the home directories of other users"),
                cUmask
              )
            )
          )
        )
      )

      helps = Ops.add(
        Ops.get_string(server_list_widget, "helps", ""),
        Ops.get_string(@HELPS, "c2", "")
      )
      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )

      UI.ChangeWidget(Id(:user), :Enabled, false)

      if user != "" && user == commonProxyName
        UI.ChangeWidget(Id(:user), :Enabled, false)
        UI.ChangeWidget(Id(:useCommonProxy), :Value, true)
      end

      if NovellLDAP.IsLocalLDAPRunning != 0
        UI.ChangeWidget(Id(:browse_workContext), :Enabled, false)
        UI.ChangeWidget(Id(:browse_partContext), :Enabled, false)
        UI.ChangeWidget(Id(:browse_admingroup), :Enabled, false)
      end

      if !(NovellLDAP.IsLocalLDAPRunning == 0 ||
          Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing")
        UI.ChangeWidget(Id(:browse_workContext), :Enabled, false)
        UI.ChangeWidget(Id(:browse_partContext), :Enabled, false)
        UI.ChangeWidget(Id(:browse_admingroup), :Enabled, false)
      else
        useBrowser = true
        UI.ChangeWidget(Id(:browse_workContext), :Enabled, true)
        UI.ChangeWidget(Id(:browse_partContext), :Enabled, true)
        UI.ChangeWidget(Id(:browse_admingroup), :Enabled, true)
      end

      if Convert.to_boolean(UI.QueryWidget(Id(:useCommonProxy), :Value))
        UI.ChangeWidget(Id(:user), :Value, commonProxyName)
        password = commonProxyPassword
      end

      PromptIfNeededForEdirAdminPassword()

      NovellLum.lum_proxy = Convert.to_boolean(
        UI.QueryWidget(Id(:useCommonProxy), :Value)
      )

      primary_server = NovellLDAP.BrowseButtonLdapServer(nil)
      ldap_servers = Ops.get_string(primary_server, "CONFIG_LDAP_SERVER_IP", "")
      ldap_sport = Ops.get_integer(
        primary_server,
        "CONFIG_LDAP_SECURE_PORT",
        636
      )
      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          # Validate input
          ldap_server = Convert.to_string(
            UI.QueryWidget(Id(:server_select), :Value)
          )

          partContext = Convert.to_string(
            UI.QueryWidget(Id(:partContext), :Value)
          )
          if !(Builtins.substring(partContext, 0, 1) == "o" ||
              Builtins.substring(partContext, 0, 2) == "dc")
            Popup.Message(
              "Unix config context should be contained in o, ou, or dc. Change the context."
            )
            next
          end
          if !NovellLum.xadMode
            if !NovellValidators.ValidateContext(partContext)
              next
            else
              partContext = ValidationHelpers.toLdap(partContext)
            end
            adminDn = Ops.get_string(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_CONTEXT",
              ""
            )
            adminPassword = Ops.get_string(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_PASSWORD",
              ""
            )

            if NovellLDAP.IsLocalLDAPRunning == 0 ||
                Ops.get_string(
                  Edirectory.EdirSettings,
                  "CONFIG_EDIR_TREE_TYPE",
                  ""
                ) == "existing"
              uco = Ops.add("cn=Unix Config,", partContext)
              if !NovellValidators.ValidateCNExists(
                  uco,
                  ldap_server,
                  "636",
                  adminDn,
                  adminPassword
                )
                goon = Popup.AnyQuestion(
                  Builtins.sformat(
                    _("The Unix Config Object (UCO), \"%1\", does not exist."),
                    uco
                  ),
                  _(
                    "Click Continue to create a new UCO and proceed.\nElse, click Cancel to enter or browse to select the existing UCO."
                  ),
                  "Continue",
                  "Cancel",
                  :focus_no
                )
                next if !goon
              end
            else
              server_list2 = NovellLDAP.GetRemoteServers(nil)
              remoteip = {}
              if Ops.greater_than(Builtins.size(server_list2), 0)
                Ops.set(
                  remoteip,
                  "CONFIG_LDAP_SERVER_IP",
                  Ops.get_string(
                    Ops.get(server_list2, 0, {}),
                    "CONFIG_LDAP_SERVER_IP",
                    ""
                  )
                )
                ldap_servers2 = Ops.get_string(
                  remoteip,
                  "CONFIG_LDAP_SERVER_IP",
                  ""
                )
                ldap_sport2 = Ops.get_integer(
                  remoteip,
                  "CONFIG_LDAP_SECURE_PORT",
                  636
                )

                uco = Ops.add("cn=Unix Config,", partContext)
                if !NovellValidators.ValidateCNExists(
                    uco,
                    ldap_servers2,
                    "636",
                    adminDn,
                    adminPassword
                  )
                  goon = Popup.AnyQuestion(
                    Builtins.sformat(
                      _("The Unix Config Object (UCO), \"%1\", does not exist."),
                      uco
                    ),
                    _(
                      "Click Continue to create a new UCO and proceed.\nElse, click Cancel to enter or browse to select the existing UCO."
                    ),
                    "Continue",
                    "Cancel",
                    :focus_no
                  )
                  next if !goon
                end
              end
            end
          else
            if partContext == nil || partContext == ""
              Popup.Error(_("A valid context must be entered."))
              next
            else
              partContext = ValidationHelpers.toLdap(partContext)
            end
          end

          workContext = Convert.to_string(
            UI.QueryWidget(Id(:workContext), :Value)
          )
          if !(Builtins.substring(Builtins.tolower(workContext), 0, 1) == "o" ||
              Builtins.substring(Builtins.tolower(workContext), 0, 2) == "dc")
            Popup.Message(
              "Unix workstation context should be contained in o, ou, or dc. Change the context."
            )
            next
          end
          workContext = "" if workContext == nil
          if NovellUtils.IsServerProduct || workContext != ""
            if !NovellLum.xadMode
              if !NovellValidators.ValidateContext(workContext)
                next
              else
                workContext = ValidationHelpers.toLdap(workContext)
              end
            else
              if workContext == nil || workContext == ""
                Popup.Error(_("A valid context must be entered."))
                next
              else
                workContext = ValidationHelpers.toLdap(workContext)
              end
            end
          end

          user = Convert.to_string(UI.QueryWidget(Id(:user), :Value))
          if user == nil || user == ""
            user = ""
          elsif Builtins.substring(Builtins.tolower(user), 0, 2) != "cn"
            Popup.Message("Select user object.")
            next
          end
          user = NovellUtils.Strip(user, " ")
          if user != nil && user != ""
            if !NovellValidators.ValidateFDN(user, false)
              next
            else
              user = ValidationHelpers.toLdap(user)
            end
            next if !NovellValidators.ValidatePassword(password)
          end
          admin_group = Convert.to_string(
            UI.QueryWidget(Id(:admin_group), :Value)
          )
          if admin_group == nil || admin_group == ""
            Popup.Message("Admin group context cannot be empty.")
            next
          elsif Builtins.substring(Builtins.tolower(admin_group), 0, 2) != "cn"
            Popup.Message("Specify Admin group name with context.")
            next
          end
          admin_group = NovellUtils.Strip(admin_group, " ")
          if admin_group != nil && admin_group != ""
            if !NovellValidators.ValidateFDN(admin_group, false)
              next
            else
              admin_group = ValidationHelpers.toLdap(admin_group)
            end
          end
          cUmask = Convert.to_boolean(UI.QueryWidget(Id(:changeUmask), :Value))
          if cUmask
            change_umask = "yes"
          else
            change_umask = "no"
          end

          Ops.set(
            NovellLum.Settings,
            "CONFIG_LUM_RESTRICT_ACCESS",
            change_umask
          )
          Ops.set(NovellLum.Settings, "CONFIG_LUM_LDAP_SERVER", ldap_server)
          Ops.set(NovellLum.Settings, "CONFIG_LUM_PARTITION_ROOT", partContext)
          if orgWorkContext != NovellUtils.Nds2Ldap(workContext)
            NovellLum.userChangedData = true
          end
          Ops.set(NovellLum.Settings, "CONFIG_LUM_WS_CONTEXT", workContext)
          Ops.set(NovellLum.Settings, "CONFIG_LUM_PROXY_USER", user)
          Ops.set(
            NovellLum.Settings,
            "CONFIG_LUM_PROXY_USER_PASSWORD",
            user.empty? ? "" : password
          )
          Ops.set(NovellLum.Settings, "CONFIG_LUM_ADMIN_GROUP", admin_group)
          if orgAdminGroup != NovellUtils.Nds2Ldap(admin_group)
            NovellLum.userChangedAdminGroup = true
          end
          break
        elsif ret == :user
          ldap_user = NovellUtils.Nds2Ldap(
            Convert.to_string(UI.QueryWidget(Id(:user), :Value))
          )
          gbl_ldap_user = ldap_user # use for prepending text value to context from browser

          next if useCommonProxy == "no"

          next if ldap_user == ""

          next if commonProxyName == ""

          if ldap_user == NovellUtils.Nds2Ldap(commonProxyName)
            UI.ChangeWidget(Id(:user), :Enabled, false)
            password = commonProxyPassword
            UI.ChangeWidget(Id(:useCommonProxy), :Value, true)
          end

          next
        elsif ret == :admin_group
          ldap_user = NovellUtils.Nds2Ldap(
            Convert.to_string(UI.QueryWidget(Id(:admin_group), :Value))
          )
          gbl_ldap_user = ldap_user # use for prepending text value to context from browser
        elsif ret == :useCommonProxy
          if Convert.to_boolean(UI.QueryWidget(Id(:useCommonProxy), :Value))
            UI.ChangeWidget(Id(:user), :Enabled, false)
            UI.ChangeWidget(Id(:user), :Value, commonProxyName)
            password = commonProxyPassword
          else
            UI.ChangeWidget(Id(:user), :Enabled, false)
            UI.ChangeWidget(Id(:password), :Enabled, false)
            UI.ChangeWidget(Id(:user), :Value, "")
            UI.ChangeWidget(Id(:password), :Value, "")
          end
          next
        elsif ret == :browse_partContext
          adminDn = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          adminPassword = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )
          if NovellLum.xadMode
            xad_tree_admin_context = Ops.get_string(
              NovellLDAP.Settings,
              "XAD_TREE_ADMIN_CONTEXT",
              ""
            )
            Builtins.y2milestone(
              "NovellLum:XAD_TREE_ADMIN_CONTEXT:%1",
              xad_tree_admin_context
            )
            if xad_tree_admin_context != nil && xad_tree_admin_context != ""
              adminDn = NovellUtils.Nds2Ldap(xad_tree_admin_context)
              adminPassword = Ops.get_string(
                NovellLDAP.Settings,
                "XAD_TREE_ADMIN_PASSWORD",
                ""
              )
            end
          end
          adminDn = NovellUtils.Nds2Ldap(adminDn)
          Builtins.y2milestone("Lum:admin:%1", adminDn)
          partContext2 = NovellLdapBrowser.LdapBrowser(
            ldap_server,
            ldap_sport,
            true,
            adminDn,
            adminPassword,
            "",
            "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country)(ObjectClass=uamPosixConfig))",
            _("Browse for container")
          )
          Builtins.y2milestone(
            Builtins.sformat(
              "dialogs.ycp.NewOrExistingDialog:container from browse is: '%1'",
              partContext2
            )
          )
          if partContext2 != nil && partContext2 != ""
            partContext2 = NovellUtils.Nds2Ldap(partContext2)
            if Builtins.substring(partContext2, 0, 3) == "cn="
              temp_partContext = NovellUtils.GetContextNDS(partContext2)
              partContext2 = NovellUtils.Nds2Ldap(temp_partContext)
            end
            UI.ChangeWidget(Id(:partContext), :Value, partContext2)
          end
        elsif ret == :browse_workContext
          adminDn = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          adminPassword = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )
          if NovellLum.xadMode
            xad_tree_admin_context = Ops.get_string(
              NovellLDAP.Settings,
              "XAD_TREE_ADMIN_CONTEXT",
              ""
            )
            Builtins.y2milestone(
              "NovellLum:XAD_TREE_ADMIN_CONTEXT:%1",
              xad_tree_admin_context
            )
            if xad_tree_admin_context != nil && xad_tree_admin_context != ""
              adminDn = NovellUtils.Nds2Ldap(xad_tree_admin_context)
              adminPassword = Ops.get_string(
                NovellLDAP.Settings,
                "XAD_TREE_ADMIN_PASSWORD",
                ""
              )
            end
          end
          adminDn = NovellUtils.Nds2Ldap(adminDn)
          Builtins.y2milestone("Lum:admin:%1", adminDn)
          workContext2 = NovellLdapBrowser.LdapBrowser(
            ldap_server,
            ldap_sport,
            true,
            adminDn,
            adminPassword,
            "",
            "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country))",
            _("Browse for container")
          )
          Builtins.y2milestone(
            Builtins.sformat(
              "dialogs.ycp.NewOrExistingDialog:container from browse is: '%1'",
              workContext2
            )
          )
          if workContext2 != nil && workContext2 != ""
            workContext2 = NovellUtils.Nds2Ldap(workContext2)
            UI.ChangeWidget(Id(:workContext), :Value, workContext2)
          end
        elsif ret == :browse_admingroup
          adminDn = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          adminPassword = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )
          if NovellLum.xadMode
            xad_tree_admin_context = Ops.get_string(
              NovellLDAP.Settings,
              "XAD_TREE_ADMIN_CONTEXT",
              ""
            )
            Builtins.y2milestone(
              "NovellLum:XAD_TREE_ADMIN_CONTEXT:%1",
              xad_tree_admin_context
            )
            if xad_tree_admin_context != nil && xad_tree_admin_context != ""
              adminDn = NovellUtils.Nds2Ldap(xad_tree_admin_context)
              adminPassword = Ops.get_string(
                NovellLDAP.Settings,
                "XAD_TREE_ADMIN_PASSWORD",
                ""
              )
            end
          end
          adminDn = NovellUtils.Nds2Ldap(adminDn)
          Builtins.y2milestone("Lum:admin:%1", adminDn)

          objFilterWithCN = "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country)(ObjectClass=Group))"
          objFilterWithNoCN = "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country))"
          objFilter = objFilterWithCN
          if Builtins.substring(gbl_ldap_user, 0, 3) == "cn="
            objFilter = objFilterWithNoCN
          else
            gbl_ldap_user = ""
            objFilter = objFilterWithCN
          end

          admin_group2 = NovellLdapBrowser.LdapBrowser(
            ldap_server,
            ldap_sport,
            true,
            adminDn,
            adminPassword,
            "",
            objFilter,
            _("Browse for group")
          )
          Builtins.y2milestone(
            "dialogs.ycp.NewOrExistingDialog:group name from browse is: '%1'",
            admin_group2
          )
          Builtins.y2milestone(
            "dialogs.ycp:admin group context text box value is %1",
            gbl_ldap_user
          )
          if admin_group2 != nil && admin_group2 != ""
            admin_group2 = NovellUtils.Nds2Ldap(admin_group2)
            if gbl_ldap_user != nil && gbl_ldap_user != ""
              gbl_ldap_user = NovellUtils.Nds2Ldap(gbl_ldap_user)
              admin_group2 = Ops.add(Ops.add(gbl_ldap_user, ","), admin_group2)
            end
            UI.ChangeWidget(Id(:admin_group), :Value, admin_group2)
          end
          Ops.set(NovellLum.Settings, "CONFIG_LUM_ADMIN_GROUP", admin_group2)
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end

      deep_copy(ret)
    end

    # Configure3 dialog
    # @return dialog result
    def OptionsDialog
      # NovellLum configure2 dialog caption
      caption = _("Linux User Management Configuration")

      login = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_SERVICE_LOGIN",
        "no"
      )
      login = NovellUtils.Strip(login, " ")
      login = Builtins.tolower(login)
      login = "no" if login == nil

      ftp = Ops.get_string(NovellLum.Settings, "CONFIG_LUM_SERVICE_FTP", "no")
      ftp = NovellUtils.Strip(ftp, " ")
      ftp = Builtins.tolower(ftp)
      ftp = "no" if ftp == nil

      sshd = Ops.get_string(NovellLum.Settings, "CONFIG_LUM_SERVICE_SSHD", "no")
      sshd = NovellUtils.Strip(sshd, " ")
      sshd = Builtins.tolower(sshd)
      sshd = "no" if sshd == nil

      su = Ops.get_string(NovellLum.Settings, "CONFIG_LUM_SERVICE_SU", "no")
      su = NovellUtils.Strip(su, " ")
      su = Builtins.tolower(su)
      su = "no" if su == nil

      sfcb = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_SERVICE_SFCB",
        "yes"
      )
      sfcb = NovellUtils.Strip(sfcb, " ")
      sfcb = Builtins.tolower(sfcb)
      sfcb = "yes" if sfcb == nil

      gdm = Ops.get_string(NovellLum.Settings, "CONFIG_LUM_SERVICE_GDM", "no")
      gdm = NovellUtils.Strip(gdm, " ")
      gdm = Builtins.tolower(gdm)
      gdm = "no" if gdm == nil

      gnome_screensaver = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_SERVICE_GNOME_SCREENSAVER",
        "no"
      )
      gnome_screensaver = NovellUtils.Strip(gnome_screensaver, " ")
      gnome_screensaver = Builtins.tolower(gnome_screensaver)
      gnome_screensaver = "no" if gnome_screensaver == nil

      gnomesu_pam = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_SERVICE_GNOMESU_PAM",
        "no"
      )
      gnomesu_pam = NovellUtils.Strip(gnomesu_pam, " ")
      gnomesu_pam = Builtins.tolower(gnomesu_pam)
      gnomesu_pam = "no" if gnomesu_pam == nil
      server_list = Ops.get_list(
        NovellLDAP.Settings,
        "CONFIG_LDAP_SERVERS_LIST",
        []
      )
      alternate_ldap_servers_list1 = []
      ldap_server = Ops.get_string(
        NovellLum.Settings,
        "CONFIG_LUM_LDAP_SERVER",
        ""
      )
      alternate_ldap_server_complete_list = []
      Builtins.foreach(server_list) do |server_info|
        if Ops.get_string(server_info, "CONFIG_LDAP_SERVER_IP", "") != ldap_server
          alternate_ldap_server_complete_list = Builtins.add(
            alternate_ldap_server_complete_list,
            server_info
          )
        end
      end

      alternate_ldap_servers_list1 = Ops.get_list(
        NovellLum.Settings,
        "CONFIG_LUM_ALTERNATE_SERVERS_LIST1",
        []
      )

      ldap_table_items = []
      id_num_t = 0

      alternate_ldap_servers_list2 = Ops.get_list(
        NovellLum.Settings,
        "CONFIG_LUM_ALTERNATE_SERVERS_LIST2",
        []
      )

      Builtins.foreach(alternate_ldap_servers_list2) do |s|
        item = Item(Id(id_num_t), s)
        ldap_table_items = Builtins.add(ldap_table_items, item)
        id_num_t = Ops.add(id_num_t, 1)
      end
      Builtins.y2milestone(
        "GUI table built time servers in table = %1",
        ldap_table_items
      )

      alternate_ldap_server_list_widget = NovellLDAPUI.ServerListWidgetAlternateLdapServers(
        alternate_ldap_server_complete_list,
        _("Existing Alternate LDAP Server(s)"),
        ldap_server,
        true,
        :multi,
        alternate_ldap_servers_list1
      )


      alternate_ldap_widget = Ops.get_term(
        alternate_ldap_server_list_widget,
        "term"
      ) { VBox(:Empty) }
      # NovellVo configure1 dialog contents
      contents = HVSquash(
        VBox(
          Ops.greater_than(
            Builtins.size(alternate_ldap_server_complete_list),
            0
          ) ?
            alternate_ldap_widget :
            Empty(),
          Label(_("Addtional Alternate LDAP Server(s) (Optional)")),
          HBox(
            VSpacing(4),
            Table(
              Id(:alternate_ldap_servers_list2),
              Opt(:notify, :immediate),
              Header(
                # table header
                _("LDAP Servers")
              ),
              #Table Items
              ldap_table_items
            )
          ),
          HBox(
            PushButton(Id(:add_ldap), _("&Add")),
            PushButton(Id(:del_ldap), _("&Delete"))
          ),
	  VSpacing(1),
          Left(
            HBox(
              Label(
                _(
                  "Click to LUM-enable the services"
                )
              ),
              HBox(Label(""), PushButton(Id(:manage_service), _("Services")))
	    )
          )
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "c3", ""),
        Label.BackButton,
        Label.NextButton
      )

      ret = nil
      while true
        ret = UI.UserInput
        if ret == :add_ldap
          newip = ""
          #877268 fetching the value of alternate_ldap_servers_list1
          alternate_ldap_servers_list1 = Convert.convert(
            UI.QueryWidget(Id(:server_select), :SelectedItems),
            :from => "any",
            :to   => "list <string>"
          )
          contents2 = HVSquash(
            VBox(
              TextEntry(Id(:serverip_t), _("LDAP &Server")),
              HBox(
                Left(PushButton(Id(:add_t), Opt(:default, :key_F3), _("&Add"))),
                Left(PushButton(Id(:cancel_t), Opt(:key_F4), _("&Cancel")))
              )
            )
          )
          UI.OpenDialog(Opt(:decorated), contents2)
          UI.SetFocus(Id(:serverip_t))
          while true
            ret2 = UI.UserInput
            if ret2 == :cancel_t
              UI.CloseDialog
              break
            elsif ret2 == :add_t
              newip = Convert.to_string(UI.QueryWidget(Id(:serverip_t), :Value))
              if !NovellValidators.ValidateDNSorIP(newip)
                # The validator has its own error message
                next
              end
              if Builtins.contains(alternate_ldap_servers_list2, newip)
                Report.Error(
                  Builtins.sformat(
                    _("An entry for the server %1 already exists."),
                    newip
                  )
                )
                next
              end
              if newip == ldap_server
                Report.Error(
                  Builtins.sformat(_("Ldap server cannot be preferred server."))
                )
                next
              end
              if Builtins.contains(alternate_ldap_servers_list1, newip)
                Report.Error(
                  Builtins.sformat(
                    _("An entry for the server %1 already exists."),
                    newip
                  )
                )
                next
              end

              UI.CloseDialog
              # Add the new ip to the servers in table list
              alternate_ldap_servers_list2 = Builtins.add(
                alternate_ldap_servers_list2,
                newip
              )
              new_item = Item(Id(id_num_t), newip)
              Builtins.y2milestone(
                "Adding %1 as to list as item %2",
                new_item,
                id_num_t
              )
              ldap_table_items = Builtins.add(ldap_table_items, new_item)
              id_num_t = Ops.add(id_num_t, 1)
              UI.ChangeWidget(
                Id(:alternate_ldap_servers_list2),
                :Items,
                ldap_table_items
              )
              break
            end
          end
        elsif ret == :del_ldap
          num = -1
          num = Convert.to_integer(
            UI.QueryWidget(Id(:alternate_ldap_servers_list2), :CurrentItem)
          )
          Builtins.y2milestone("Entry to delete num = %1", num)
          next if num == nil
          if Ops.greater_or_equal(num, 0)
            alternate_ldap_servers_list2 = Builtins.remove(
              alternate_ldap_servers_list2,
              num
            )
            ldap_table_items = Builtins.remove(ldap_table_items, num)
            #Recompress the table
            id_num_t = 0
            new_table = []
            Builtins.foreach(ldap_table_items) do |t|
              item = Item(Id(id_num_t), Ops.get_string(t, 1, ""))
              new_table = Builtins.add(new_table, item)
              id_num_t = Ops.add(id_num_t, 1)
            end
            ldap_table_items = deep_copy(new_table)
            UI.ChangeWidget(
              Id(:alternate_ldap_servers_list2),
              :Items,
              ldap_table_items
            )
            Builtins.y2milestone(
              "ldap_table_items after delete = %1",
              ldap_table_items
            )
            next
          end
        end

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :manage_service
          return_values = ServicesOption(login, ftp, sshd, su, sfcb, gdm, gnome_screensaver, gnomesu_pam)

          login = return_values[0]
          ftp = return_values[1]
          sshd = return_values[2]
          su = return_values[3]
          sfcb = return_values[4]
          gdm = return_values[5]
          gnome_screensaver = return_values[6]
          gnomesu_pam = return_values[7]

        elsif ret == :next
          if Ops.greater_than(
              Builtins.size(alternate_ldap_server_complete_list),
              0
            )
            alternate_ldap_servers_list1 = Convert.convert(
              UI.QueryWidget(Id(:server_select), :SelectedItems),
              :from => "any",
              :to   => "list <string>"
            )
            Ops.set(
              NovellLum.Settings,
              "CONFIG_LUM_ALTERNATE_SERVERS_LIST1",
              alternate_ldap_servers_list1
            )
          end
          Ops.set(
            NovellLum.Settings,
            "CONFIG_LUM_ALTERNATE_SERVERS_LIST2",
            alternate_ldap_servers_list2
          )

          Ops.set(NovellLum.Settings, "CONFIG_LUM_SERVICE_LOGIN", login)
          Ops.set(NovellLum.Settings, "CONFIG_LUM_SERVICE_FTP", ftp)
          Ops.set(NovellLum.Settings, "CONFIG_LUM_SERVICE_SSHD", sshd)
          Ops.set(NovellLum.Settings, "CONFIG_LUM_SERVICE_SU", su)
          Ops.set(NovellLum.Settings, "CONFIG_LUM_SERVICE_SFCB", sfcb)
          Ops.set(NovellLum.Settings, "CONFIG_LUM_SERVICE_GDM", gdm)
          Ops.set(
            NovellLum.Settings,
            "CONFIG_LUM_SERVICE_GNOME_SCREENSAVER",
            gnome_screensaver
          )
          Ops.set(
            NovellLum.Settings,
            "CONFIG_LUM_SERVICE_GNOMESU_PAM",
            gnomesu_pam
          )

          break
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end

      deep_copy(ret)
    end

    def ServicesOption(login, ftp, sshd, su, sfcb, gdm, gnome_screensaver, gnomesu_pam)
      if login == "yes" && ftp == "yes" && sshd == "yes" && su == "yes" && sfcb == "yes" && gdm == "yes" && gnome_screensaver == "yes" && gnomesu_pam == "yes"
        allServices = true
      else
        allServices = false
      end

      UI.OpenDialog(
        Opt(:decorated),
        MinWidth(60,
          VBox(
            VSpacing(0.5),
              VBox(
                HBox(
                  HSpacing(3),
                  Left(
                    Label(
                      _(
                        "Select the services to LUM-enable on this server."
                      )
                    )
                  )
                ),
                HBox(
                  HSpacing(3),
                  Left(
                    CheckBox(Id(:selectAll), Opt(:notify, :immediate), _("All Services"), allServices))
                ),
                HBox(
                  HSpacing(3),
                  HWeight(50,
                    VBox(
                      Left(
                        CheckBox(
                           Id(:ftp),
                           _("&ftp"),
                           ftp == "yes"
                        )
                      )
                    )
                  ),
                  HWeight(50,
                    VBox(
                      Left(
                        CheckBox(
                           Id(:gdm),
                           _("&gdm"),
                           gdm == "yes"
                        )
                      )
                    )
                  )
                ),
                HBox(
                  HSpacing(3),
                  HWeight(50,
                    VBox(
                      Left(
                        CheckBox(
                           Id(:gnome_screensaver),
                           _("gnome-s&creensaver"),
                           gnome_screensaver == "yes"
                        )
                      )
                    )
                  ),
                  HWeight(50,
                    VBox(
                      Left(
                        CheckBox(
                           Id(:gnomesu_pam),
                           _("gnomesu-pa&m"),
                           gnomesu_pam == "yes"
                        )
                      )
                    )
                  )
                ),
                HBox(
                  HSpacing(3),
                  HWeight(50,
                    VBox(
                      Left(
                        CheckBox(
                           Id(:login),
                           _("&login"),
                           login == "yes"
                        )
                      )
                    )
                  ),
                  HWeight(50,
                    VBox(
                      Left(
                        CheckBox(
                           Id(:sfcb),
                           _("sf&cb"),
                           sfcb == "yes"
                        )
                      )
                    )
                  )
                ),
                HBox(
                  HSpacing(3),
                  HWeight(50,
                    VBox(
                      Left(
                        CheckBox(
                           Id(:sshd),
                           _("ssh&d"),
                           sshd == "yes"
                        )
                      )
                    )
                  ),
                  HWeight(50,
                    VBox(
                      Left(
                        CheckBox(
                           Id(:su),
                           _("s&u"),
                           su == "yes"
                        )
                      )
                    )
                  )
                ),
                VSpacing(0.5),
                HBox(
                  Right(
                    PushButton(Id(:ok), Opt(:default), Label.OKButton)
                  ),
                  HSpacing(2),
                ),
                VSpacing(0.5),
            )
        )
       )
      )

      while true
        ret = UI.UserInput
        if ret == :ok
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:login), :Value))
          login = tmp == true ? "yes" : "no"
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:ftp), :Value))
          ftp = tmp == true ? "yes" : "no"
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:sshd), :Value))
          sshd = tmp == true ? "yes" : "no"
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:su), :Value))
          su = tmp == true ? "yes" : "no"
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:sfcb), :Value))
          sfcb = tmp == true ? "yes" : "no"
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:gdm), :Value))
          gdm = tmp == true ? "yes" : "no"
          tmp = Convert.to_boolean(
            UI.QueryWidget(Id(:gnome_screensaver), :Value)
          )
          gnome_screensaver = tmp == true ? "yes" : "no"
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:gnomesu_pam), :Value))
          gnomesu_pam = tmp == true ? "yes" : "no"

          UI.CloseDialog
          return login, ftp, sshd, su, sfcb, gdm, gnome_screensaver, gnomesu_pam
        elsif ret == :selectAll
          if Convert.to_boolean(UI.QueryWidget(Id(:selectAll), :Value))
            UI.ChangeWidget(Id(:login), :Value, true)
            UI.ChangeWidget(Id(:ftp), :Value, true)
            UI.ChangeWidget(Id(:sshd), :Value, true)
            UI.ChangeWidget(Id(:su), :Value, true)
            UI.ChangeWidget(Id(:sfcb), :Value, true)
            UI.ChangeWidget(Id(:gdm), :Value, true)
            UI.ChangeWidget(Id(:gnome_screensaver), :Value, true)
            UI.ChangeWidget(Id(:gnomesu_pam), :Value, true)
          else
            UI.ChangeWidget(Id(:login), :Value, false)
            UI.ChangeWidget(Id(:ftp), :Value, false)
            UI.ChangeWidget(Id(:sshd), :Value, false)
            UI.ChangeWidget(Id(:su), :Value, false)
            UI.ChangeWidget(Id(:sfcb), :Value, false)
            UI.ChangeWidget(Id(:gdm), :Value, false)
            UI.ChangeWidget(Id(:gnome_screensaver), :Value, false)
            UI.ChangeWidget(Id(:gnomesu_pam), :Value, false)
	  end
	elsif ret == :cancel
	    UI.CloseDialog
	    return login, ftp, sshd, su, sfcb, gdm, gnome_screensaver, gnomesu_pam
        end
      end
    end
  end
end
