# encoding: utf-8

# Copyright (c) 2022 Micro Focus or one of its affiliates.
# File:	include/novell-lum/helps.ycp
# Package:	Configuration of novell-lum
# Summary:	Help texts of all the dialogs
# Authors:	Mark Clark <mclark@novell.com>, Steve Bearnson <SBEARNSON@novell.com>
#
# $Id: helps.ycp,v 1.1.2.7 2005/02/11 01:00:29 mclark Exp $
module Yast
  module NovellLumHelpsInclude
    def initialize_novell_lum_helps(include_target)
      textdomain "novell-lum"

      # All helps are here
      @HELPS = {
        # Read dialog help 1/2
        "read"  => _(
          "<p><b><big>Initializing Linux User Management Configuration</big></b><br>\nPlease wait...</p>\n"
        ) +
          # Read dialog help 2/2
          _(
            "<p><b><big>Aborting Initialization:</big></b><br>\nSafely stop the configuration utility by clicking <b>Abort</b> now.</p>\n"
          ),
        # Write dialog help 1/2
        "write" => _(
          "<p><b><big>Saving Linux User Management Configuration</big></b><br>\nPlease wait...</p>\n"
        ) +
          # Write dialog help 2/2
          _(
            "<p><b><big>Aborting Saving</big></b><br>\n" +
              "Stop the save procedure by clicking <b>Abort</b>.\n" +
              "This opens an additional dialog that indicates whether it is safe to do so.</p>\n"
          ),
        # Configure2 dialog help 1/4
        "c2"    => _(
          "<p><b><big>Unix Config Context</big></b><br>\n" +
            "Browse or enter the Unix Config Context, the Unix Config object holds a list of the locations (contexts) of Unix Workstation objects in eDirectory. It also controls the range of numbers to be assigned as UIDs and GIDs when User objects and Group objects are created.</p>\n" +
            "<p>Specify the eDirectory context (existing or created here) where the Unix Config object will be created. An LDAP search for a LUM User, a LUM Group, or a LUM Workstation object begins here, so the context must be at the same level or higher than the LUM objects searched for.</p>\n" +
            "<p>If the Unix Config Object is placed below the location of the User objects, the /etc/nam.conf file on the target computer must include the support-outside-base-context=yes parameter.</p>\n" +
            "<p>Geographically dispersed networks might require multiple Unix Config objects in a single tree, but most networks need only one Unix Config object in eDirectory.</p>\n" +
            "<p><b>Warning: Avoid editing this field if this server is being added to a Domain Services for Windows tree/domain.</b></p>\n"
        ) +
          # Configure2 dialog help 2/4
          _(
            "<p><b><big>Unix Workstation Context</big></b><br>\n" +
              "Browse or enter the Unix Workstation Context, computers running Linux User Management (LUM) are represented by Unix Workstation objects in eDirectory. The object holds the set of properties and information associated with the target computer, such as the target workstation name or a list of eDirectory groups that have access to the target workstation.</p>\n" +
              "\n" +
              "\n" +
              "<p>Specify the eDirectory context (existing or created here) for the Unix Workstation object created by the install for this server. The context should be the same as or below the Unix Config Context specified above.</p>\n" +
              "<p><b>Warning: Avoid editing this field if this server is being added to a Domain Services for Windows tree/domain.</b></p>\n"
          ) +
          _(
            "<p><b><big>Admin group name with  Context</big></b><br>\nBrowse or enter the admin group name. The admin group will be created if it does not exist and will be LUM-enabled. The admin user that is used to configure the LUM service will be added to this admin group and this group will be associated with the workstation object. By default, this field will be populated with the group name 'admingroup' which will be created in the admin user context.</p>\n"
          ) +
          # Configure2 dialog help 3/4
          _(
            "<p><b><big>Proxy User for LUM Management (Optional)</big></b><br>\n" +
              "This is the Common Proxy user that was created during eDirectory configuration for managing LUM service.</p>\n" +
              "<p>On selecting the 'Use OES Common Proxy User' check box the proxy user fields are populated with common proxy user name. These values are specified during eDirectory configuration if you have selected the 'Use Common Proxy User as default for OES Products' check box.</p>\n"
          ) +
          # Configure2 dialog help 4/4
          _(
            "<p><b><big>Restrict Access to the Home Directories of Other Users</big></b><br>\n" +
              "This option is selected by default to restrict read and write access for users other than the owner to  home directories.</p>\n" +
              "<p>Using the default selection changes the umask setting in /etc/nam.conf from 022 to 077.</p>\n"
          ) +
          _(
            "<p><b>Note:</b> If you modify the LUM configuration parameters in nam.conf, the changes will not be reflected in the LUM YaST configuration.\nYou must ensure that the nam.conf and the configuration file at the location /etc/sysconfig/novell are in sync.</p>\n"
          ),
        # Configure3 dialog help 1/3
        "c3"    => _(
          "<p><b><big>Existing Alternate LDAP Server(s)</big></b><br>\nLists the IP addresses / hostnames of the local server and the remote eDirectory server that you are connecting to. To specify an alternate LDAP server, select the check box next to the IP address / hostname in the list. You can select multiple LDAP servers.</p>\n"
        ) +
          _(
            "<p><b><big>Addtional Alternate LDAP Server(s) (Optional)</big></b><br>\nClick Add to specify one or more external LDAP servers. You must ensure that you specify the IP address / hostname of a valid LDAP server that is up and running.</p>\n"
          ) +
          _(
            "<p><b><big>Services to LUM-Enable</big></b><br>\nClick Services to LUM-enable the services on this server. The services will be available to authenticated LUM users.</p>\n"
          ) +
          # Configure3 dialog help 2/3
          _(
            "<p><b><big>SFCB</big></b><br>\nSFCB is selected by default because it is used by many of the OES services such as iPrint, NSS, SMS, OES Remote Manager, and Samba. To get access to iManager, you must enable SFCB.</p>\n"
          ) +
          # Configure3 dialog help 3/3
          _(
            "<p><b>SSHD and NetStorage</b><br>If you want to use the SSH protocol to define a NetStorage storage location object so your users can use SSH to have access to local files or files on another server in the same eDirectory tree, you must select SSHD as a LUM-enabled service.</p>\n<p>If you do not select SSHD, users cannot log in to NetStorage through SSH to access their files.</p>\n"
          )
      } 

      # EOF
    end
  end
end
