# encoding: utf-8

# File:	include/novell-lum/wizards.ycp
# Package:	Configuration of novell-lum
# Summary:	Wizards definitions
# Authors:	Stephen T. Bunch <sbunch@novell.com>
#
# $Id: wizards.ycp,v 1.1.2.3 2004/12/03 00:04:42 sbunch Exp $
module Yast
  module NovellLumWizardsInclude
    def initialize_novell_lum_wizards(include_target)
      Yast.import "UI"

      textdomain "novell-lum"

      Yast.import "Sequencer"
      Yast.import "Wizard"

      Yast.include include_target, "novell-lum/complex.rb"
      Yast.include include_target, "novell-lum/dialogs.rb"
    end

    # Main workflow of the novell-lum configuration
    # @return sequence result
    def MainSequence
      aliases = { "lum" => lambda { LumDialog() }, "options" => lambda do
        OptionsDialog()
      end }

      sequence = {
        "ws_start" => "lum",
        "lum"      => { :abort => :abort, :next => "options", :skip => :next },
        "options"  => { :abort => :abort, :next => :next }
      }

      ret = Sequencer.Run(aliases, sequence)

      deep_copy(ret)
    end

    # Whole configuration of novell-lum
    # @return sequence result
    def NovellLumSequence
      aliases = {
        "read"  => [lambda { ReadDialog() }, true],
        "main"  => lambda { MainSequence() },
        "write" => [lambda { WriteDialog() }, true]
      }

      sequence = {
        "ws_start" => "read",
        "read"     => { :abort => :abort, :next => "main" },
        "main"     => { :abort => :abort, :next => "write" },
        "write"    => { :abort => :abort, :next => :next }
      }

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("novell-lum")

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # Whole configuration of novell-lum but without reading and writing.
    # For use with autoinstallation.
    # @return sequence result
    def NovellLumAutoSequence
      # Initialization dialog caption
      caption = _("Linux User Mgmt Configuration")
      # Initialization dialog contents
      contents = Label(_("Initializing..."))

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("novell-lum")
      Wizard.SetContentsButtons(
        caption,
        contents,
        "",
        Label.BackButton,
        Label.NextButton
      )

      ret = MainSequence()

      UI.CloseDialog
      deep_copy(ret)
    end
  end
end
